#[repr(u8)]pub enum BindingDirection {
Args = 0,
Response = 1,
}Expand description
Whether a method schema binding describes args or the response type.
Variants
Args = 0
The sender will send data of this type as method arguments.
Response = 1
The sender will send data of this type as the method response.