#[repr(u8)]pub enum SchemaKind<Id = SchemaHash> {
Struct {
name: String,
fields: Vec<FieldSchema<Id>>,
},
Enum {
name: String,
variants: Vec<VariantSchema<Id>>,
},
Tuple {
elements: Vec<TypeRef<Id>>,
},
List {
element: TypeRef<Id>,
},
Map {
key: TypeRef<Id>,
value: TypeRef<Id>,
},
Array {
element: TypeRef<Id>,
length: u64,
},
Option {
element: TypeRef<Id>,
},
Channel {
direction: ChannelDirection,
element: TypeRef<Id>,
},
Primitive {
primitive_type: PrimitiveType,
},
}Expand description
The structural kind of a type, generic over the ID representation.
Variants
Struct
Fields

name: StringThe type name (e.g. “Point”). Used for matching across schema versions and for diagnostics. MUST NOT be empty.

fields: Vec<FieldSchema<Id>>Enum
Fields

name: StringThe type name (e.g. “Color”). Used for matching across schema versions and for diagnostics. MUST NOT be empty.

variants: Vec<VariantSchema<Id>>Tuple
List
Map
Array
Option
Channel
Primitive
Fields

primitive_type: PrimitiveTypeImplementations
Sourceimpl<Id> SchemaKind<Id>
impl<Id> SchemaKind<Id>
Sourcepub fn for_each_type_ref(&self, f: &mut impl FnMut(&TypeRef<Id>))
pub fn for_each_type_ref(&self, f: &mut impl FnMut(&TypeRef<Id>))
Visit every TypeRef in this schema kind.
Sourcepub fn try_map_type_refs<OtherId, E>(
self,
f: &mut impl FnMut(TypeRef<Id>) -> Result<TypeRef<OtherId>, E>,
) -> Result<SchemaKind<OtherId>, E>
pub fn try_map_type_refs<OtherId, E>( self, f: &mut impl FnMut(TypeRef<Id>) -> Result<TypeRef<OtherId>, E>, ) -> Result<SchemaKind<OtherId>, E>
Transform every TypeRef in this schema kind, with fallible mapping.