SchemaSource

Trait SchemaSource 

pub trait SchemaSource {
    // Required method
    fn get_schema(&self, id: SchemaHash) -> Option<Schema>;
}
Anything that can look up schemas by their content hash.

Implemented by SchemaRegistry (HashMap), the operation store, etc. Used by the send tracker to source schemas without caring where they come from.

Required Methods

Implementations on Foreign Types

Source

impl SchemaSource for HashMap<SchemaHash, Schema>

Implementors