ClientRequest

Struct ClientRequest 

pub struct ClientRequest<'call, 'state> { /* private fields */ }
Borrowed request wrapper exposed to client middleware.

This allows middleware to add dynamic metadata while keeping the backing storage alive until the wrapped caller finishes sending the request.

Implementations

Source

impl<'call, 'state> ClientRequest<'call, 'state>

pub fn call(&self) -> &RequestCall<'call>

pub fn metadata(&self) -> &[MetadataEntry<'call>]

pub fn metadata_mut(&mut self) -> &mut Metadata<'call>

pub fn push_string_metadata( &mut self, key: &'static str, value: impl Into<String>, flags: MetadataFlags, )

pub fn push_bytes_metadata( &mut self, key: &'static str, value: impl Into<Vec<u8>>, flags: MetadataFlags, )

pub fn push_u64_metadata( &mut self, key: &'static str, value: u64, flags: MetadataFlags, )