HandshakeResult

Struct HandshakeResult 

pub struct HandshakeResult {
    pub role: SessionRole,
    pub our_settings: ConnectionSettings,
    pub peer_settings: ConnectionSettings,
    pub peer_supports_retry: bool,
    pub session_resume_key: Option<SessionResumeKey>,
    pub peer_resume_key: Option<SessionResumeKey>,
    pub our_schema: Vec<Schema>,
    pub peer_schema: Vec<Schema>,
}
Result of a completed CBOR handshake.

Fields

role: SessionRoleour_settings: ConnectionSettingspeer_settings: ConnectionSettingspeer_supports_retry: boolsession_resume_key: Option<SessionResumeKey>

The resume key for this session. For the acceptor, this is the key we generated and sent in HelloYourself. For the initiator, this is the key the acceptor sent us.

peer_resume_key: Option<SessionResumeKey>

The resume key the peer sent in their Hello (initiator→acceptor only). Used by the acceptor to look up existing sessions for resumption.

our_schema: Vec<Schema>peer_schema: Vec<Schema>