pub struct MetadataEntry<'a> {
pub key: Cow<'a, str>,
pub value: MetadataValue<'a>,
pub flags: MetadataFlags,
}Expand description
A single metadata entry with a key, value, and flags.
Uses Cow for the key so entries can be borrowed (from wire data) or owned.
Fields
key: Cow<'a, str>value: MetadataValue<'a>flags: MetadataFlagsImplementations
Sourceimpl<'a> MetadataEntry<'a>
impl<'a> MetadataEntry<'a>
Sourcepub fn str(key: impl Into<Cow<'a, str>>, value: impl Into<Cow<'a, str>>) -> Self
pub fn str(key: impl Into<Cow<'a, str>>, value: impl Into<Cow<'a, str>>) -> Self
Create a string metadata entry with no flags.
Sourcepub fn u64(key: impl Into<Cow<'a, str>>, value: u64) -> Self
pub fn u64(key: impl Into<Cow<'a, str>>, value: u64) -> Self
Create a u64 metadata entry with no flags.
Sourcepub fn bytes(
key: impl Into<Cow<'a, str>>,
value: impl Into<Cow<'a, [u8]>>,
) -> Self
pub fn bytes( key: impl Into<Cow<'a, str>>, value: impl Into<Cow<'a, [u8]>>, ) -> Self
Create a bytes metadata entry with no flags.
Sourcepub fn with_flags(self, flags: MetadataFlags) -> Self
pub fn with_flags(self, flags: MetadataFlags) -> Self
Set flags on this entry.
Sourcepub fn into_owned(self) -> MetadataEntry<'static>
pub fn into_owned(self) -> MetadataEntry<'static>
Convert to a 'static lifetime by cloning any borrowed data.