pub struct ServerResponseContext { /* private fields */ }Expand description
Owned context available when observing an outbound server response.
Implementations
Sourceimpl ServerResponseContext
impl ServerResponseContext
Sourcepub const fn new(
method: &'static MethodDescriptor,
request_id: Option<RequestId>,
connection_id: Option<ConnectionId>,
extensions: Extensions,
) -> Self
pub const fn new( method: &'static MethodDescriptor, request_id: Option<RequestId>, connection_id: Option<ConnectionId>, extensions: Extensions, ) -> Self
Create a response context from transport identifiers and shared extensions.
Sourcepub const fn method(&self) -> &'static MethodDescriptor
pub const fn method(&self) -> &'static MethodDescriptor
Static descriptor for the method being handled.
Sourcepub const fn request_id(&self) -> Option<RequestId>
pub const fn request_id(&self) -> Option<RequestId>
Wire-level request identifier for this call, when available.
Sourcepub const fn connection_id(&self) -> Option<ConnectionId>
pub const fn connection_id(&self) -> Option<ConnectionId>
Virtual connection identifier for this call, when available.
Sourcepub const fn extensions(&self) -> &Extensions
pub const fn extensions(&self) -> &Extensions
Per-request middleware extensions bag.