pub type BoxFut<'a, T> = Pin<Box<dyn MaybeSendFuture<Output = T> + 'a>>;Expand description
A boxed future that is Send on native targets and !Send on wasm32.
Aliased Type
pub struct BoxFut<'a, T> { /* private fields */ }pub type BoxFut<'a, T> = Pin<Box<dyn MaybeSendFuture<Output = T> + 'a>>;A boxed future that is Send on native targets and !Send on wasm32.
pub struct BoxFut<'a, T> { /* private fields */ }