pub trait SchemaSource {
// Required method
fn get_schema(&self, id: SchemaHash) -> Option<Schema>;
}Expand description
Anything that can look up schemas by their content hash.
Implemented by SchemaRegistry (HashMap), the operation store, etc. Used by the send tracker to source schemas without caring where they come from.