pub struct HandshakeResult {
pub role: SessionRole,
pub our_settings: ConnectionSettings,
pub peer_settings: ConnectionSettings,
pub peer_supports_retry: bool,
pub session_resume_key: Option<SessionResumeKey>,
pub peer_resume_key: Option<SessionResumeKey>,
pub our_schema: Vec<Schema>,
pub peer_schema: Vec<Schema>,
}Expand description
Result of a completed CBOR handshake.
Fields
role: SessionRoleour_settings: ConnectionSettingspeer_settings: ConnectionSettingspeer_supports_retry: boolsession_resume_key: Option<SessionResumeKey>The resume key for this session. For the acceptor, this is the key we generated and sent in HelloYourself. For the initiator, this is the key the acceptor sent us.
peer_resume_key: Option<SessionResumeKey>The resume key the peer sent in their Hello (initiator→acceptor only). Used by the acceptor to look up existing sessions for resumption.
our_schema: Vec<Schema>peer_schema: Vec<Schema>Trait Implementations
Sourceimpl Clone for HandshakeResult
impl Clone for HandshakeResult
Sourcefn clone(&self) -> HandshakeResult
fn clone(&self) -> HandshakeResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for HandshakeResult
impl RefUnwindSafe for HandshakeResult
impl Send for HandshakeResult
impl Sync for HandshakeResult
impl Unpin for HandshakeResult
impl UnsafeUnpin for HandshakeResult
impl UnwindSafe for HandshakeResult